/* log.c */

/*
  SquidClamav - A Clamav Antivirus Redirector for Squid
  
  This project is a modified version of the excellent Squirm Redirector
  for Squid Maintained by Chris Foote, and copyrighted
  as follow :

  Copyright (C) 1998 Chris Foote & Wayne Piekarski

  The original Squirm version used was squirm-1.0betaB. Some other parts
  are cut and paste from the ex1.c program given in the ClamAv distribution
  and are copyrighted: Copyright (C) 2002 - 2004 Tomasz Kojm

  All other code: Copyright (C) 2005 Gilles Darold - Groupe SAMSE


  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
  Please see the file GPL in this directory for full copyright
  information.
*/


#include"paths.h"
#include"squidclamav.h"
#include"log.h"
#include<stdio.h>
#include<time.h>
#include<stdlib.h>
#include<string.h>
#include <sys/types.h>
#include <unistd.h>

static char *get_date(void);

extern int interactive;       /* from main.c */

void logit(char *filename, char *format, ...)
{
  FILE *log;
  char *date_str = NULL;
  char msg[MAX_BUFF];
  va_list args;

  
  va_start(args, format);
  if (vsnprintf(msg, (MAX_BUFF*2)+1, format, args) < 0) {
    /* Can't format log, so just return */
    return;
  }
  va_end(args);

  date_str = get_date();
  if ( (interactive != 0) || (filename == NULL) ) {
    fprintf(stderr, "%s %s", date_str, msg);
    if (fflush(stderr) != 0)
       fprintf(stderr, "%s ERROR %s", date_str, "Error flushing log stream\n");
  } else {
    log = fopen(filename, "at");
    if (log == NULL) {
	fprintf(stderr, "%s ERROR %s", date_str, "Error opening log stream\n");
	fprintf(stderr, "%s %s", date_str, msg);
    } else {
	    fprintf(log, "%s [%d] %s", date_str, (int)getpid(), msg);
	    if (fflush(log) != 0)
		fprintf(stderr, "%s ERROR %s", date_str, "Error flushing log stream\n");
	    if (fclose(log) != 0)
		fprintf(stderr, "%s ERROR %s", date_str, "Error closing log stream\n");
	}
  }
  free(date_str);
}


char *get_date(void)
{
  time_t tp;
  char *ascitime;
  char *s;
  
  tp = time(NULL);
  
  ascitime = ctime(&tp);
  
  s = (char *)malloc(sizeof(char) * (strlen(ascitime)+1));
  if(s == NULL) {
    fprintf(stderr, "FATAL: unable to allocate memory in get_date()\n");
    exit(EXIT_FAILURE); /* no use writing an error message, because this function
                will keep getting called! */
  }
  strcpy(s, ascitime);
  s[strlen(ascitime) - 1] = '\0';
  
  return s;
}













